=== modified file 'ivle/webapp/admin/subject.py'
--- ivle/webapp/admin/subject.py	2010-02-15 08:39:41 +0000
+++ ivle/webapp/admin/subject.py	2010-02-15 08:49:58 +0000
@@ -70,8 +70,6 @@
         ctx['req'] = req
         ctx['user'] = req.user
         ctx['semesters'] = []
-        ctx['mediapath'] = media_url(req, CorePlugin, 'images/')
-        ctx['SubjectEdit'] = SubjectEdit
 
         for semester in req.store.find(Semester).order_by(Desc(Semester.year),
                                                      Desc(Semester.semester)):
@@ -84,9 +82,24 @@
             if len(offerings):
                 ctx['semesters'].append((semester, offerings))
 
-        # Admins get a separate list of subjects so they can add/edit.
-        if req.user.admin:
-            ctx['subjects'] = req.store.find(Subject).order_by(Subject.name)
+
+class SubjectsManage(XHTMLView):
+    '''Subject management view.'''
+    template = 'templates/subjects-manage.html'
+    tab = 'subjects'
+
+    def authorize(self, req):
+        return req.user is not None and req.user.admin
+
+    def populate(self, req, ctx):
+        ctx['req'] = req
+        ctx['mediapath'] = media_url(req, CorePlugin, 'images/')
+        ctx['SubjectEdit'] = SubjectEdit
+        ctx['SemesterEdit'] = SemesterEdit
+
+        ctx['subjects'] = req.store.find(Subject).order_by(Subject.name)
+        ctx['semesters'] = req.store.find(Semester).order_by(
+            Semester.year, Semester.semester)
 
 
 class SubjectShortNameUniquenessValidator(formencode.FancyValidator):
@@ -608,6 +621,7 @@
         subject_url, semester_url, offering_url, projectset_url, project_url)
 
     views = [(ApplicationRoot, ('subjects', '+index'), SubjectsView),
+             (ApplicationRoot, ('subjects', '+manage'), SubjectsManage),
              (ApplicationRoot, ('subjects', '+new'), SubjectNew),
              (ApplicationRoot, ('subjects', '+new-offering'), OfferingNew),
              (ApplicationRoot, ('+semesters', '+new'), SemesterNew),

=== added file 'ivle/webapp/admin/templates/subjects-manage.html'
--- ivle/webapp/admin/templates/subjects-manage.html	1970-01-01 00:00:00 +0000
+++ ivle/webapp/admin/templates/subjects-manage.html	2010-02-15 08:49:58 +0000
@@ -0,0 +1,49 @@
+<html xmlns="http://www.w3.org/1999/xhtml"
+      xmlns:py="http://genshi.edgewall.org/">
+  <head>
+    <title>Manage subjects</title>
+  </head>
+  <body>
+    <h1>Manage subjects</h1>
+    <div id="ivle_padding">
+      <div class="majorsection">
+        <h2>Subjects</h2>
+        <table class="pretty_table">
+          <thead><tr><th>Subject</th><th>Code</th><th>Actions</th></tr></thead>
+          <tbody>
+            <tr py:for="subject in subjects">
+              <td>${subject.name}</td>
+              <td>${subject.code}</td>
+              <td>
+                <a href="${req.publisher.generate(subject, SubjectEdit)}" title="Edit"><img src="${mediapath + 'interface/pencil.png'}" alt="Edit" /></a>
+              </td>
+            </tr>
+          </tbody>
+        </table>
+        <div class="horizontalactions">
+          <a class="addaction" href="/subjects/+new">Create new subject</a>
+          <a class="addaction" href="/subjects/+new-offering">Create new offering</a>
+        </div>
+      </div>
+      <div class="majorsection">
+        <h2>Semesters</h2>
+        <table class="pretty_table">
+          <thead><tr><th>Year</th><th>Semester</th><th>State</th><th>Actions</th></tr></thead>
+          <tbody>
+            <tr py:for="semester in semesters">
+              <td>${semester.year}</td>
+              <td>${semester.semester}</td>
+              <td>${semester.state}</td>
+              <td>
+                <a href="${req.publisher.generate(semester, SemesterEdit)}" title="Edit"><img src="${mediapath + 'interface/pencil.png'}" alt="Edit" /></a>
+              </td>
+            </tr>
+          </tbody>
+        </table>
+        <div class="horizontalactions">
+          <a class="addaction" href="/+semesters/+new">Create new semester</a>
+        </div>
+      </div>
+    </div>
+  </body>
+</html>

=== modified file 'ivle/webapp/admin/templates/subjects.html'
--- ivle/webapp/admin/templates/subjects.html	2010-02-15 07:30:52 +0000
+++ ivle/webapp/admin/templates/subjects.html	2010-02-15 08:49:58 +0000
@@ -17,25 +17,9 @@
           </li>
         </ul>
       </py:for>
-      <py:if test="defined('subjects')">
-        <h1>All subjects</h1>
-        <table class="pretty_table">
-          <thead><tr><th>Subject</th><th>Code</th><th>Actions</th></tr></thead>
-          <tbody>
-            <tr py:for="subject in subjects">
-              <td>${subject.name}</td>
-              <td>${subject.code}</td>
-              <td>
-                <a href="${req.publisher.generate(subject, SubjectEdit)}" title="Edit"><img src="${mediapath + 'interface/pencil.png'}" alt="Edit" /></a>
-              </td>
-            </tr>
-          </tbody>
-        </table>
-        <div class="horizontalactions">
-          <a class="addaction" href="/subjects/+new">Create new subject</a>
-          <a class="addaction" href="/subjects/+new-offering">Create new offering</a>
-        </div>
-      </py:if>
+      <div py:if="req.user.admin">
+        <a class="manageaction" href="/subjects/+manage">Manage subjects</a>
+      </div>
     </div>
   </body>
 </html>

